#!/bin/bash
# Syncplify.me AFT! installation script
# Repair/Upgrade functions


do_repair_upgrade() {
	echo

	if service_exists syncplify-me-aft; then
	  echo "AFT! service found, stopping it..."
	  sudo systemctl disable syncplify-me-aft
	  sudo systemctl stop syncplify-me-aft
	  sleep 0.5
	  echo "AFT! service stopped"
	fi

	echo "Copying main executable file..."
	sudo cp -p ./bin/syncplify-me-aft /usr/bin/syncplify-me-aft
	sudo chmod +x /usr/bin/syncplify-me-aft

	echo "Copying service descriptor..."
	sudo cp -p ./svc/syncplify-me-aft.service /etc/systemd/system/syncplify-me-aft.service
	sudo chmod 644 /etc/systemd/system/syncplify-me-aft.service

	echo "Ensuring directory structure is correct..."
	sudo mkdir -p /etc/xdg/Syncplify.me/AFTv1/certs
	sudo mkdir -p /etc/xdg/Syncplify.me/AFTv1/modules

	echo "Verifying existence of EK value..."
	if ! file_exists /etc/xdg/Syncplify.me/AFTv1/env.conf
	then
	  exesudo ensure_ek_systemd
	else
	  echo "EK found, kept existing one"
	fi

	echo "Deploying management interface..."
	sudo rm -r -f /etc/xdg/Syncplify.me/AFTv1/manage
	sudo cp -r ./manage /etc/xdg/Syncplify.me/AFTv1/manage
	
	echo "Deploying modules..."
	sudo rm -r -f /etc/xdg/Syncplify.me/AFTv1/modules
	sudo cp -r ./manage /etc/xdg/Syncplify.me/AFTv1/modules

	echo "Checking existence of digital certificates..."
	if ! file_exists "/etc/xdg/Syncplify.me/AFTv1/certs/server.key" ; then
	  sudo cp -r -i ./certs/server.key /etc/xdg/Syncplify.me/AFTv1/certs/server.key
	  echo "New self-signed certificate key installed"
	fi

	if ! file_exists "/etc/xdg/Syncplify.me/AFTv1/certs/server.crt" ; then
	  sudo cp -r -i ./certs/server.crt /etc/xdg/Syncplify.me/AFTv1/certs/server.crt
	  echo "New self-signed certificate installed"
	fi

	echo "Ensuring availability of setup shell scripts..."
	sudo mkdir -p /usr/bin/syncplify-me-aft-setup
	sudo cp -p ./setup.sh /usr/bin/syncplify-me-aft-setup/setup.sh
	sudo cp -r ./functions /usr/bin/syncplify-me-aft-setup/functions

	echo "Starting AFT! service..."
	sudo systemctl start syncplify-me-aft
	sudo systemctl enable syncplify-me-aft
	sleep 0.5
	echo "DONE"
	echo
	echo "AFT! is avilable at https://127.0.0.1:44399/"
	echo
	xdg-open "https://127.0.0.1:44399/"
}
